------------
Known Issues
------------

  * Creating a Jp2 file with the irreversible option does not work
    on windows.
  * Eval-ing a :py:meth:`repr` string does not work on windows.

-------
Roadmap
-------

  * Glymur version 0.8.13 will mark the transition of 0.8.x into an LTS series,
    i.e. bug fixes only with few exceptions.
  * Glymur version 0.9.0 will drop support for Python 2.7 and OpenJPEG 1.5.
